![](https://raw.githubusercontent.com/u1i/bambleweeny/master/img/bwy2.png)

# b9y - Python Bindings for Bambleweeny

A client implementation for [Bamblweeny](https://github.com/u1i/bambleweeny)

## Install
pip install b9y


## PyPi

[b9y-cli on pypi](https://pypi.org/project/b9y/)
